@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Nicolas Burrus
+# Copyright (C) 2005, 2006, 2007, 2008 Nicolas Burrus
 # This file is part of Tidydoc.
 #
 # Tidydoc is free software; you can redistribute it and/or modify
@@ -66,24 +66,25 @@ def parse(desc_file):
 def docname_from_dsc(sections, orig_file):
   try:
     title = sections['Title'][0].lower()
-    title = re.sub('[^\w]+', '_', title)
+    title = re.sub('[^\w]+', '_', title.rstrip("\r\n"))
   except:
     raise "Error: no title"
 
   try:
     conf = sections['Conf'][0].lower()
-    conf = re.sub('[^\w]+', '_', conf)
+    conf = re.sub('[^\w]+', '_', conf.rstrip("\r\n"))
   except:
     conf = ""
 
   try:
-    author = sections['Author'][0].lower()
+    author = sections['Author'][0].lower().rstrip("\r\n")
     author = author.split(' ')[-1]
+    author = re.sub('[^\w]+', '_', author)
   except:
     author = "unknown"
 
   try:
-    date = re.match('.*\d\d(\d\d).*', sections['Date'][0]).group(1)
+    date = re.match('.*\d\d(\d\d).*', sections['Date'][0]).group(1).rstrip("\r\n")
   except:
     date = ""
 
@@ -98,7 +99,6 @@ def docname_from_dsc(sections, orig_file):
   return filename
 
 def doc_filename_from_dsc(dsc):
-  files = glob(re.sub('\.dsc$', '*', dsc))
-  for f in files:
-    if not re.match('.*\.dsc$', f) and not re.match('.*\.xml$', f):
-      return f
+  return dsc.rstrip('.dsc')
+
+
